@@ -20,10 +20,9 @@
 #define KFTABDLG_H
 
 #include <QMimeType>
-#include <QValidator> // for KDigitValidator
-
-#include <ktabwidget.h>
+#include <QTabWidget>
 #include <QUrl>
+#include <QValidator> // for KDigitValidator
 
 class KUrlComboBox;
 class QButtonGroup;
@@ -35,14 +34,14 @@ class QString;
 class QDate;
 class QRegExp;
 class KDateComboBox;
-class KDialog;
+class QDialog;
 class KComboBox;
 class QSpinBox;
 class QLabel;
 
 class KfDirDialog;
 
-class KfindTabWidget : public KTabWidget
+class KfindTabWidget : public QTabWidget
 {
     Q_OBJECT
 
